# About

## Thanks to:

The development of [badgers](https://github.com/Fraunhofer-IESE/badgers) was initially driven by Julien Siebert at the Data Science Department of the Fraunhofer Institute for Experimental Software Engineering ([IESE](https://www.iese.fraunhofer.de/)) in Kaiserslautern, Germany.

The original idea came during internal discussions with Patricia Kelbert, Adam Trendowicz, and Michael Kläs.

A big thanks to Daniel Seifert for taking the time to investigate and automate all the many things that make our lives as package contributors easier.

## Citing Badgers

If you use [badgers](https://github.com/Fraunhofer-IESE/badgers) in scientific publications, you can cite the following paper:

Julien Siebert, Daniel Seifert, Patricia Kelbert, Michael Kläs, Adam Trendowicz (2023). Badgers: generating data quality deficits with Python. https://arxiv.org/abs/2307.04468

```
@misc{siebert2023badgers,
      title={Badgers: generating data quality deficits with Python}, 
      author={Julien Siebert and Daniel Seifert and Patricia Kelbert and Michael Kläs and Adam Trendowicz},
      year={2023},
      eprint={2307.04468},
      archivePrefix={arXiv},
      primaryClass={cs.LG}
}
```

## Contributing to Badgers

Every contribution is welcome, please have a look at [dev-tutorials](../dev/Create-New-Tabular-Generators/) section and [CONTRIBUTING.md](https://github.com/Fraunhofer-IESE/badgers/blob/main/CONTRIBUTING.md) for more info.




